/**
 * @copyright nhcarrigan
 * @license Naomi's Public License
 * @author Naomi Carrigan
 */

import type { onRequestHookHandler } from "fastify";

/**
 * Ensures that form submissions only come from our web application.
 * @param request - The request payload from the server.
 * @param response - The reply handler from Fastify.
 * @returns A Fastify reply if the request is invalid, otherwise undefined.
 */
// eslint-disable-next-line @typescript-eslint/no-misused-promises -- For reasons I cannot comprehend, Fastify seems to require us to return a request?
export const corsHook: onRequestHookHandler = async(request, response) => {
  if (!request.url.startsWith("/submit")) {
    return undefined;
  }
  if (request.headers.origin !== "https://forms.nhcarrigan.com") {
    return await response.
      status(403).
      send({
        error: "Forms can only be submitted through our website. Thanks.",
      });
  }
  return undefined;
};
